/*****************************************************************************
 *
 *  gtkhg - simple gtk2 wrapper library.
 *
 * Copyright (c) 2007 Hyo geol, Lee
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 *   3. The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/
// 	$Id: gtkhg.hpp,v 1.5 2007/01/07 21:47:17 ez8 Exp $	
#ifndef GTKHG_H
#define GTKHG_H

#include <gtk/gtk.h>

#include "smartptr.hpp"

namespace HG {

    /// @brief RAII helper class to lock graphic function 
    ///        in threads environments.
    class GdkLock {
    public:
        explicit GdkLock();
        ~GdkLock();
    private:
        GdkLock(const GdkLock&);
        GdkLock& operator=(const GdkLock&);
    };

    template <typename T>
    struct GFreeDestructor {

        static void Destroy(T* p)
        {
            if(p)
                g_free((void*)(p));
        }
    };

    template <typename T>
    struct GFreeHelper {

        typedef DestPtr<T, GFreeDestructor> Type;
    };

    typedef GFreeHelper<gchar>::Type GCharPtr;

    /// @brief RAII helper class for GtkTreePath, free at destructor 
    ///        if has path.
    class GtkTreePathHelper {
    public:
        //explicit GtkTreePathHelper(GtkTreePath* path = 0);

        /// @brief Get path from current cursor of view
        explicit GtkTreePathHelper(GtkTreeView* view);

        ~GtkTreePathHelper();

        //GtkTreePath* Get();

        bool IsExist() const;

        GCharPtr GetString() const;

    private:
        GtkTreePath* path_;

        GtkTreePathHelper(const GtkTreePathHelper&);
        GtkTreePathHelper& operator=(const GtkTreePathHelper&);
    };
}

/// inline functions.
using namespace HG;

inline GdkLock::GdkLock()
{
    gdk_threads_enter();
}

inline GdkLock::~GdkLock()
{
    gdk_flush();
    gdk_threads_leave();
}

/*
inline GtkTreePathHelper::GtkTreePathHelper(GtkTreePath* path)
    : path_(path)
{}
*/

inline GtkTreePathHelper::GtkTreePathHelper(GtkTreeView* view)
{
    gtk_tree_view_get_cursor(view, &path_, NULL);
}

inline GtkTreePathHelper::~GtkTreePathHelper()
{
    if(path_)
        gtk_tree_path_free(path_);
}

/*
inline GtkTreePath* GtkTreePathHelper::Get()
{
    return path_;
}
*/

inline bool GtkTreePathHelper::IsExist() const
{
    return path_ != 0;
}

inline GCharPtr GtkTreePathHelper::GetString() const
{
    return GCharPtr(gtk_tree_path_to_string(path_));
}

#endif
