/*****************************************************************************
 *
 *  kv5500 - utility library for kv5500 like phone.
 *
 * Copyright (c) 2006-2007 Hyo geol, Lee
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 *   3. The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/
#include "kv5500_file.hpp"

using namespace KV5500;

void KV5500::PrintFileInfoVec(const std::vector<FileInfo>& v)
{
    if(v.empty()) {

        printf("Nothing.\n");

        return;
    }

    const unsigned int total = v.size();
    const std::vector<FileInfo>::const_iterator end = v.end();
    unsigned int count = 1;
    for(std::vector<FileInfo>::const_iterator i = v.begin();
        i != end;
        ++i, ++count) {

        printf("-------------------------------------------%03d/%03d---\n", count, total);
        PrintFileInfo(*i);
    }
}

const char* FileGetNum::what() const throw()
{
    return "Request file number error.";
}

int KV5500::RecvName(UsbDev& udev, std::string& name)
{
    char buf[1000];
    const int ret = udev.BulkRead(buf, sizeof(buf), 5000);

    /// assume ret must be over 37 bytes.
    if(ret <= 37)
        return -1;

    name = GetString(buf, 26, 11, 26, 0x00);

    return ret;
}

int KV5500::RecvSize(UsbDev& udev, unsigned int& size)
{
    char buf[1000];
    const int ret = udev.BulkRead(buf, sizeof(buf), 5000);

    /// assume ret must be over 54 bytes.
    if(ret <= 11)
        return -1;

    size = GetRevEndian(buf + 8);

    return ret;
}

bool KV5500::GetTotalNum(UsbDev& udev, char* const req, size_t reqSize, unsigned int& num)
{
    assert(req && reqSize > 2);

    if(udev.BulkWrite(req, reqSize, 5000) < 0) {

        printf("Got error while send.\n");

        return false;
    }

    return RecvNum(udev, num);
}

bool KV5500::RecvNum(UsbDev& udev, unsigned int& num)
{
    char rbuf[1000];
    const int ret = udev.BulkRead(rbuf, sizeof(rbuf), 5000);
    if(ret < 8)
        return false;

    num = static_cast<unsigned int>(rbuf[5]);

    return true;
}

unsigned int KV5500::GetPrefixPos(const char* const buf)
{
    assert(buf);

    unsigned int prefix = 0;
    unsigned int prefixCount = 0;
    while(prefixCount != 12) {

        prefix += HasSubstStr(buf, prefix) ? 2 : 1;

        ++prefixCount;
    }

    return prefix;
}
