/*****************************************************************************
 *
 *  kv5500_sms - read a sms from kv5500 like phone.
 *
 * Copyright (c) 2006-2007 Hyo geol, Lee
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 *   3. The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/
#ifndef SMS_H
#define SMS_H

#include <string>

namespace KV5500 {

    class SMS {
    public:
        SMS(const std::string& number, const char* date, const std::string& msg);

        const std::string& GetNumber() const;
        const std::string& GetDate() const;
        const std::string& GetMessage() const;

        void SetNumber(const char* str);
        void SetDate(const char* str);
        void SetMessage(const char* str);

    private:
        std::string number_;
        std::string date_;
        std::string message_;
    };
}

/// inline functions.
using namespace KV5500;

inline SMS::SMS(const std::string& number, const char* date, const std::string& msg)
    : number_(number),
      date_(date),
      message_(msg)
{}

inline const std::string& SMS::GetNumber() const
{
    return number_;
}

inline const std::string& SMS::GetDate() const
{
    return date_;
}

inline const std::string& SMS::GetMessage() const
{
    return message_;
}

inline void SMS::SetNumber(const char* str)
{
    number_ = str;
}

inline void SMS::SetDate(const char* str)
{
    date_ = str;
}

inline void SMS::SetMessage(const char* str)
{
    message_ = str;
}

#endif
